<?php

namespace Tricks\MediaLibraryOverrides\Data;

use Spatie\LaravelData\Data;

class ImageDimensionData extends Data
{
    public function __construct(
        public int $width,
        public int $height,
    ) {
    }
}
