<?php

namespace Tricks\MediaLibraryOverrides\Data;

use App\Data\TranslatedData;
use Spatie\LaravelData\Data;

class TranslatedImageData extends Data
{
    public function __construct(
        public string $url,
        public TranslatedData $alt,
    ) {
    }

    public static function fromMultiple(string $url, TranslatedData $alt): self
    {
        return new self($url, $alt);
    }
}
