<?php

namespace Tricks\MediaLibraryOverrides\Data;

use Spatie\LaravelData\Data;

class OgImageData extends Data
{
    public function __construct(
        public string $url,
    ) {
    }

    public static function fromString(string $string): OgImageData
    {
        return new self($string);
    }
}
