<?php

use Tricks\MediaLibraryOverrides\ResponsiveImages\WidthCalculator\StaticWidthsCalculator;

return [

    'responsive_images' => [
        'width_calculator' => StaticWidthsCalculator::class,
        'use_tiny_placeholders' => false,
        'tiny_placeholder_generator' => Spatie\MediaLibrary\ResponsiveImages\TinyPlaceholderGenerator\Blurred::class,
    ],

    // 'nuxt-screens' => [320, 640, 1280],
];
